# daterange
A cli tool that iterates through a range of dates

Get a range of dates:
```shell script
daterange -s 2020-01-01 -e 2020-01-05
2020-01-01 2020-01-02 2020-01-03 2020-01-04 2020-01-05
```

Get a range of hours:
to be supported

How to install:

```shell script
pip install date-range-cli==0.0.3
```